@@ -6,7 +6,7 @@ package Parallel::Depend::Queue;
 
 use v5.10;
 use strict;
-use vars qw( $job_id_sep $nspace_sep );
+use vars qw( $job_id_sep );
 
 use File::Basename;
 
@@ -18,19 +18,11 @@ use Symbol                  qw( qualify_to_ref );
 # package variables
 ########################################################################
 
-our $VERSION    = v1.2.0;
+our $VERSION    = v1.0.0;
 
 my $empty       = {};
 
-*job_id_sep     = \qq{$;};
-*nspace_sep     = \q{.};
-
-my @no_inherit_attrz
-= qw
-(
-    ad_hoc
-    alias
-);
+*job_id_sep     = \"$;";
 
 ########################################################################
 # public interface
@@ -56,8 +48,8 @@ sub construct
 
 sub init
 {
-    # populate the queue structure, load the
-    # initial arguments as attributes.
+    # return the existing que if it exists otherwise
+    # install a que if one is supplied otherwise die.
     
     my $que     = shift;
 
@@ -74,6 +66,12 @@ sub init
 
     %$que =
     (
+        # used within _attrib, _alias to separate out
+        # individual jobs. contents are managed by the
+        # $mgr object.
+
+        namespace   => '',
+
         # defined by the schedule.
         # { prior }{ $job } => jobs that run prior to $job.
         # { after }{ $job } => jobs that run after $job.
@@ -90,8 +88,9 @@ sub init
 
         # stderr, stdout, runfile paths for each job.
         #
-        # prefix used to generate the basenames of 
-        # all files.
+        # prefix is added before logdir and rundir entries
+        # with the name to avoid basename collisions for jobs
+        # aliased in mutiple groups.
 
         prefix  => $base,
 
@@ -115,153 +114,62 @@ sub init
 # $que->foo( $new_context ) when preparing or 
 # executing the schedule.
 
-for
-(
-    [ alias   => []                 ],
-    [ attrib  => \@no_inherit_attrz ],
-)
+for my $type ( qw( alias attrib ) )
 {
-    my ( $type, $purge ) = @$_;
+    my $get = qualify_to_ref $type;
+    my $has = qualify_to_ref 'has_' . $type;
 
-    my $key     = '_' . $type;
-
-    my $get     = qualify_to_ref $type;
+    my $key = '_' . $type;
 
     *$get
     = sub
     {
-        my ( $que, $nspace ) = @_;
+        my ( $que, $contxt ) = @_;
 
-        $nspace //= $que->{ namespace } || '';
+        $contxt //= $que->{ namespace };
 
-        my $a   = $que->{ $key };
+        $que->{ $key }{ $contxt }
+        ||= +{ %{ $que->{ $type } } }
+    };
 
-        $a->{ $nspace }
-        ||= do
-        {
-            my %b   = %{ $que->{ $type } };
+    *$has
+    = sub
+    {
+        my ( $que, $subkey ) = @_;
 
-            delete @b{ @$purge };
-
-            \%b
-        }
+        $subkey ~~ $que->{ $type }
     };
 }
 
-sub purge_group
-{
-    my ( $que, $group ) = @_;
-
-    my $job_id  = $que->job_id( $group );
-
-    my $grp_id  = $que->namespace( $group );
-
-    for( @{ $que }{ qw( _attrib _alias ) } )
-    {
-        delete @{ $_ }{ ( $grp_id, $job_id ) };
-    }
-
-    return
-}
-
-########################################################################
-# these keep $job_id_sep and $nspace_sep private.
-
-sub namespace
-{
-    my $que = shift;
-
-    exists $que->{ namespace }
-    or log_fatal 'Bogus namespace: queue missing namespace';
-
-    defined ( my $nspace  = $que->{ namespace } )
-    or log_fatal "Damaged queue: undefined namespace", $que;
-
-    if( $nspace && @_ )
-    {
-        join $nspace_sep, $que->{ namespace }, $_[0]
-    }
-    elsif( @_ )
-    {
-        $_[0]
-    }
-    else
-    {
-        $nspace
-    }
-}
-
-sub job_id
-{
-    my $que = shift;
-
-    @_ 
-    ? join $job_id_sep, $que->{ namespace }, $_[0]
-    : $que->{ namespace } . $job_id_sep
-}
-
-sub job_id_split
-{
-    my ( $que, $job_id ) = @_;
-
-    $job_id //= $que->{ job_id }
-    or log_fatal 'Bogus job_id_split: missing job_id';
-
-    split /$job_id_sep/o, $job_id, 2
-}
-
-sub job_name
-{
-    my $que = shift;
-
-    my $job = shift // $que->{ job }
-    or log_fatal 'Bogus job_name: missing job';
-
-    my $i = index $job, $job_id_sep;
-
-    $i < 0
-    ? $job
-    : substr $job, ++$i
-}
-
-sub resolve_alias
-{
-    my $que     = shift;
-    my $job     = $que->job_name( @_ );
-
-    my $alias
-    = $que->{ alias }{ $job }
-    // $que->attrib->{ alias }
-    // $job
-    ;
-
-    wantarray
-    ? ( $alias => $job )
-    : $alias
-}
-
-
 ########################################################################
 # mainly used to merge attributes from jobs with the currently
 # context's attributes. 
 
 sub merge_attrib
 {
-    my $que         = shift;
+    my $que     = shift;
 
-    my ( $alias, $name ) = $que->resolve_alias( @_ );
-     
-    my $nspace      = $que->namespace;
+    my $context
+    = 2 == @_
+    ? join $job_id_sep, @_
+    : 1 == @_ 
+    ? shift
+    : log_fatal 'Bogus job_attrib: invalid argument count', \@_
+    ;
 
-    my $attrz       = $que->{ _attrib };
+    my $global  = $que->attrib;
 
-    my $global      = $que->attrib;
-    my $alias_attrz = $attrz->{ $nspace, $alias } || $empty;
-    my $job_attrz   = $attrz->{ $nspace, $name  } || $empty;
-
-    wantarray
-    ?  ( %$global, %$alias_attrz, %$job_attrz )
-    : +{ %$global, %$alias_attrz, %$job_attrz }
+    if( my $local = $que->{ _attrib }{ $context } )
+    {
+        +{
+            %$global,
+            %$local,
+        }
+    }
+    else
+    {
+        $global
+    }
 }
 
 sub set_job_attrib
@@ -287,23 +195,6 @@ sub set_job_attrib
     return
 }
 
-sub get_job_attrib
-{
-    my $que     = shift;
-
-    my $job     = shift 
-    or log_fatal "Bogus set_job_attrib: missing job argument";
-
-    my $nspace  = $que->{ namespace };
-
-    my $attrz   = $que->{ _attrib }{ $nspace, $job }
-    or return;
-
-    wantarray
-    ? @{ $attrz }{ @_ }
-    : $attrz->{ $_[0] }
-}
-
 # keep require happy
 
 1
